@@ -6,14 +6,14 @@
   @Date: 2022-08-09 15:33:43
   @Description:
   @Email: noaghzil@gmail.com
-  @Last Modified time: 2022-08-15 17:23:40
+  @Last Modified time: 2022-08-16 17:43:49
 """
 import time
 from datetime import datetime
 from turtle import pd
 import redis
 import pytest
-from tool_box import ex_cache
+from min_tbox import ex_cache
 
 @pytest.fixture(scope="session")
 def rds_client():
